==> igniteui-react-charts-16.6.8.tgz: package/ES2015/PercentagePriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentagePriceOscillatorIndicatorStrategy } from "./PercentagePriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class PercentagePriceOscillatorIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new PercentagePriceOscillatorIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return PercentagePriceOscillatorIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get shortPeriod() {
        return typeGetValue(this.c(PercentagePriceOscillatorIndicator.qr));
    }
    set shortPeriod(a) {
        this.h(PercentagePriceOscillatorIndicator.qr, a);
    }
    qd() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(PercentagePriceOscillatorIndicator.qq));
    }
    set longPeriod(a) {
        this.h(PercentagePriceOscillatorIndicator.qq, a);
    }
    qa() {
        return this.longPeriod;
    }
}
PercentagePriceOscillatorIndicator.$t = markType(PercentagePriceOscillatorIndicator, 'PercentagePriceOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
PercentagePriceOscillatorIndicator.qr = StrategyBasedIndicator.qp(10, PercentagePriceOscillatorIndicator.$);
PercentagePriceOscillatorIndicator.qq = StrategyBasedIndicator.ql(30, PercentagePriceOscillatorIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/PercentagePriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentagePriceOscillatorIndicatorStrategy } from "./PercentagePriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class PercentagePriceOscillatorIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new PercentagePriceOscillatorIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return PercentagePriceOscillatorIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get shortPeriod() {
        return typeGetValue(this.c(PercentagePriceOscillatorIndicator.qy));
    }
    set shortPeriod(a) {
        this.h(PercentagePriceOscillatorIndicator.qy, a);
    }
    qk() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(PercentagePriceOscillatorIndicator.qx));
    }
    set longPeriod(a) {
        this.h(PercentagePriceOscillatorIndicator.qx, a);
    }
    qh() {
        return this.longPeriod;
    }
}
PercentagePriceOscillatorIndicator.$t = markType(PercentagePriceOscillatorIndicator, 'PercentagePriceOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
PercentagePriceOscillatorIndicator.qy = StrategyBasedIndicator.qw(10, PercentagePriceOscillatorIndicator.$);
PercentagePriceOscillatorIndicator.qx = StrategyBasedIndicator.qs(30, PercentagePriceOscillatorIndicator.$);
